On 2021/10/20 16:05, Eric Auger wrote:
Hi

On 10/14/21 3:22 PM, Yanan Wang wrote:
Generate PPTT table for Arm virt machines.
Generate the Processor Properties Topology Table (PPTT) for ARM virt
machines supporting it (>= 6.2)
Ok, much clearer. I will add it to the commit msg.

Thanks,
Yanan
.
Signed-off-by: Yanan Wang <wangyana...@huawei.com>
Reviewed-by: Andrew Jones <drjo...@redhat.com>
---
  hw/arm/virt-acpi-build.c | 8 +++++++-
  1 file changed, 7 insertions(+), 1 deletion(-)

diff --git a/hw/arm/virt-acpi-build.c b/hw/arm/virt-acpi-build.c
index 6cec97352b..658a0a5d39 100644
--- a/hw/arm/virt-acpi-build.c
+++ b/hw/arm/virt-acpi-build.c
@@ -875,13 +875,19 @@ void virt_acpi_build(VirtMachineState *vms, 
AcpiBuildTables *tables)
      dsdt = tables_blob->len;
      build_dsdt(tables_blob, tables->linker, vms);
  /* FADT MADT GTDT MCFG SPCR pointed to by RSDT */
      acpi_add_table(table_offsets, tables_blob);
      build_fadt_rev5(tables_blob, tables->linker, vms, dsdt);
acpi_add_table(table_offsets, tables_blob);
      build_madt(tables_blob, tables->linker, vms);
+ if (!vmc->no_cpu_topology) {
+        acpi_add_table(table_offsets, tables_blob);
+        build_pptt(tables_blob, tables->linker, ms,
+                   vms->oem_id, vms->oem_table_id);
+    }
+
      acpi_add_table(table_offsets, tables_blob);
      build_gtdt(tables_blob, tables->linker, vms);
@@ -875,13 +875,19 @@ void virt_acpi_build(VirtMachineState *vms, 
      dsdt = tables_blob->len;
      build_dsdt(tables_blob, tables->linker, vms);
- /* FADT MADT GTDT MCFG SPCR pointed to by RSDT */
+    /* FADT MADT PPTT GTDT MCFG SPCR pointed to by RSDT */
      acpi_add_table(table_offsets, tables_blob);
      build_fadt_rev5(tables_blob, tables->linker, vms, dsdt);
Besides
Reviewed-by: Eric Auger <eric.au...@redhat.com>

Eric

.


Reply via email to